summaryrefslogtreecommitdiff
path: root/PC/winreg.c
diff options
context:
space:
mode:
authorluzpaz <luzpaz@users.noreply.github.com>2017-11-05 07:37:50 -0600
committerSerhiy Storchaka <storchaka@gmail.com>2017-11-05 15:37:50 +0200
commita5293b4ff2c1b5446947b4986f98ecf5d52432d4 (patch)
treebe2f5e686be63814c02eabc61a899631ec7a08ac /PC/winreg.c
parentcf296537f164abeacd83011239881f75f290ed31 (diff)
downloadcpython-git-a5293b4ff2c1b5446947b4986f98ecf5d52432d4.tar.gz
Fix miscellaneous typos (#4275)
Diffstat (limited to 'PC/winreg.c')
-rw-r--r--PC/winreg.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/PC/winreg.c b/PC/winreg.c
index 2d665f7318..ddaf3b1abc 100644
--- a/PC/winreg.c
+++ b/PC/winreg.c
@@ -25,7 +25,7 @@ static char errNotAHandle[] = "Object is not a handle";
/* The win32api module reports the function name that failed,
but this concept is not in the Python core.
- Hopefully it will one day, and in the meantime I dont
+ Hopefully it will one day, and in the meantime I don't
want to lose this info...
*/
#define PyErr_SetFromWindowsErrWithFunction(rc, fnname) \
@@ -506,9 +506,9 @@ PyWinObject_CloseHKEY(PyObject *obHandle)
** Note that fixupMultiSZ and countString have both had changes
** made to support "incorrect strings". The registry specification
** calls for strings to be terminated with 2 null bytes. It seems
** some commercial packages install strings which dont conform,
** causing this code to fail - however, "regedit" etc still work
** with these strings (ie only we dont!).
*/
static void
fixupMultiSZ(wchar_t **str, wchar_t *data, int len)
@@ -506,9 +506,9 @@ PyWinObject_CloseHKEY(PyObject *obHandle)
** made to support "incorrect strings". The registry specification
** calls for strings to be terminated with 2 null bytes. It seems
-** some commercial packages install strings which dont conform,
+** some commercial packages install strings which don't conform,
** causing this code to fail - however, "regedit" etc still work
@@ -506,9 +506,9 @@ PyWinObject_CloseHKEY(PyObject *obHandle)
** causing this code to fail - however, "regedit" etc still work
-** with these strings (ie only we dont!).
+** with these strings (ie only we don't!).
*/
static void